@@ -36,6 +36,7 @@
 #include <mars/interfaces/graphics/GraphicsManagerInterface.h>
 #include <mars/data_broker/DataPackage.h>
 #include <mars/sim/CameraSensor.h>
+#include <mars/sim/SimNode.h>
 #include <mars/app/MARS.h>
 #include <mars/utils/misc.h>
 #ifdef __unix__
@@ -84,6 +85,7 @@ namespace mars {
         }
         updateGraphics = false;
         nextStep = false;
+        updateTime = -1.0;
         if(control->graphics) {
           pf = new osg_points::PointsFactory();
           lf = new osg_lines::LinesFactory();
@@ -125,6 +127,11 @@ namespace mars {
             ConfigMap::iterator it = map.find("stopSim");
             map.erase(it);
           }
+          if(map.hasKey("resetSim") && (bool)map["resetSim"]) {
+            ConfigMap::iterator it = map.find("resetSim");
+            map.erase(it);
+            control->sim->resetSim(false);
+          }
           if(map.hasKey("quitSim") && (bool)map["quitSim"]) {
             ConfigMap::iterator it = map.find("quitSim");
             map.erase(it);
@@ -174,6 +181,72 @@ namespace mars {
             map.erase(iit);
           }
 
+          if(map.hasKey("configMotorValues")) {
+            ConfigMap::iterator it = map["configMotorValues"].beginMap();
+            for(; it!=map["configMotorValues"].endMap(); ++it) {
+              std::string name = it->first;
+              if(it->second.hasKey("value")) {
+                double value = it->second["value"];
+                if(motorMap.find(name) == motorMap.end()) {
+                  unsigned long id = control->motors->getID(name);
+                  if(id) {
+                    motorMap[name] = id;
+                    control->motors->setOfflinePosition(id, value);
+                  }
+                }
+                else {
+                  control->motors->setOfflinePosition(motorMap[name], value);
+                }
+              }
+            }
+            ConfigMap::iterator iit = map.find("configMotorValues");
+            map.erase(iit);
+          }
+
+          if(map.hasKey("applyForce") && control->sim->isSimRunning()) {
+            ConfigMap::iterator it = map["applyForce"].beginMap();
+            for(; it!=map["applyForce"].endMap(); ++it) {
+              std::string name = it->first;
+              if(it->second.hasKey("value")) {
+                ConfigVector v = it->second["value"];
+                if(nodeMap.find(name) == nodeMap.end()) {
+                  unsigned long id = control->nodes->getID(name);
+                  if(id) {
+                    nodeMap[name] = id;
+                    control->nodes->applyForce(id, Vector(v[0], v[1], v[2]), Vector(v[3], v[4], v[5]));
+                  }
+                }
+                else {
+                  control->nodes->applyForce(nodeMap[name], Vector(v[0], v[1], v[2]), Vector(v[3], v[4], v[5]));
+                }
+              }
+            }
+            ConfigMap::iterator iit = map.find("applyForce");
+            map.erase(iit);
+          }
+
+          if(map.hasKey("applyTorque") && control->sim->isSimRunning()) {
+            ConfigMap::iterator it = map["applyTorque"].beginMap();
+            for(; it!=map["applyTorque"].endMap(); ++it) {
+              std::string name = it->first;
+              if(it->second.hasKey("value")) {
+                ConfigVector v = it->second["value"];
+                if(nodeMap.find(name) == nodeMap.end()) {
+                  unsigned long id = control->nodes->getID(name);
+                  if(id) {
+                    nodeMap[name] = id;
+                    control->nodes->applyTorque(id, Vector(v[0], v[1], v[2]));
+                  }
+                }
+                else {
+                  control->nodes->applyTorque(nodeMap[name], Vector(v[0], v[1], v[2]));
+                }
+              }
+            }
+            ConfigMap::iterator iit = map.find("applyTorque");
+            map.erase(iit);
+          }
+
           if(map.hasKey("config")) {
             ConfigMap::iterator it = map["config"].beginMap();
             for(; it!=map["config"].endMap(); ++it) {
@@ -189,8 +262,7 @@ namespace mars {
                 info = control->cfg->getParamInfo(group, name);
                 switch(info.type) {
                 case cfg_manager::boolParam:
-                  control->cfg->setProperty(group, name,
-                                            (bool)atoi(value.c_str()));
+                  control->cfg->setProperty(group, name, (bool)atoi(value.c_str()));
                   break;
                 case cfg_manager::doubleParam:
                   control->cfg->setProperty(group, name, atof(value.c_str()));
@@ -267,6 +339,16 @@ namespace mars {
                 }
               }
             }
+            if(map["edit"].hasKey("materials")) {
+              for(auto it: (ConfigMap&)(map["edit"]["materials"])) {
+                std::string name = it.first;
+                for(auto it2: (ConfigVector&)it.second) {
+                  std::string key = it2["k"];
+                  std::string value = it2["v"];
+                  control->graphics->editMaterial(name, key, value);
+                }
+              }
+            }
             if(map["edit"].hasKey("graphics") && control->graphics) {
               for(auto it: (ConfigMap&)(map["edit"]["graphics"])) {
                 int id = atoi(it.first.c_str());
@@ -496,7 +578,18 @@ namespace mars {
 
       void PythonMars::reset() {
         motorMap.clear();
+        nodeMap.clear();
         //plugin->reload();
+        try {
+          ConfigItem map;
+          toConfigMap(plugin->function("reset").call(0).returnObject(), map);
+          interpreteMap(map);
+          interpreteGuiMaps();
+        }
+        catch(const std::exception &e) {
+          LOG_FATAL("Error: %s", e.what());
+          pythonException = true;
+        }
       }
 
       void PythonMars::update(sReal time_ms) {
@@ -529,15 +622,20 @@ namespace mars {
 
             if(type == "Node") {
               unsigned long id = control->nodes->getID(name);
-              Vector pos = control->nodes->getPosition(id);
-              Quaternion rot = control->nodes->getRotation(id);
-              sendMap["Nodes"][name]["pos"]["x"] = pos.x();
-              sendMap["Nodes"][name]["pos"]["y"] = pos.y();
-              sendMap["Nodes"][name]["pos"]["z"] = pos.z();
-              sendMap["Nodes"][name]["rot"]["x"] = rot.x();
-              sendMap["Nodes"][name]["rot"]["y"] = rot.y();
-              sendMap["Nodes"][name]["rot"]["z"] = rot.z();
-              sendMap["Nodes"][name]["rot"]["w"] = rot.w();
+              if(id) {
+                sim::SimNode *node = control->nodes->getSimNode(id);
+                Vector pos = node->getPosition();
+                Quaternion rot = node->getRotation();
+                bool contact = node->getGroundContact();
+                sendMap["Nodes"][name]["pos"]["x"] = pos.x();
+                sendMap["Nodes"][name]["pos"]["y"] = pos.y();
+                sendMap["Nodes"][name]["pos"]["z"] = pos.z();
+                sendMap["Nodes"][name]["rot"]["x"] = rot.x();
+                sendMap["Nodes"][name]["rot"]["y"] = rot.y();
+                sendMap["Nodes"][name]["rot"]["z"] = rot.z();
+                sendMap["Nodes"][name]["rot"]["w"] = rot.w();
+                sendMap["Nodes"][name]["contact"] = contact;
+              }
             }
 
             if(type == "Motor") {
